from amis import App, PageSchema, Flex, ActionType, LevelEnum, Dialog, Form, DisplayModeEnum, InputText, TableColumn, \
    CRUD, Tpl, Switch
from amis import Html, Page, Property, Service, Divider

logo = Html(html=f'''
<p align="center">
    <a href="https://github.com/YouthLearning/TeenStudy/">
        <img src="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
         width="256" height="256" alt="TeenStudy">
    </a>
</p>
<h2 align="center">大学习自动提交</h2>
<div align="center">
    <a href="https://github.com/YouthLearning/TeenStudy/" target="_blank">
    Github仓库</a>
    <a href="https://jq.qq.com/?_wv=1027&k=NGFEwXyS" target="_blank">交流群</a>
    <a href="http://qm.qq.com/cgi-bin/qm/qr?_wv=1027&k=2PQucjirnkHyPjoS1Pkr-ai2aPGToBKm" target="_blank">QQ体验群</a>
</div>
<br>
''')
github_logo = Tpl(className='w-full',
                  tpl='<div class="flex justify-between"><div></div><div><a href="https://github.com/YouthLearning/TeenStudy" target="_blank" title="Github 仓库"><i class="fab fa-github fa-2x"></i></a></div></div>')
header = Flex(className='w-full', justify='flex-end', alignItems='flex-end', items=[github_logo, {
    "type": "button",
    "label": "退出",
    "onEvent": {
        "click": {
            "actions": [
                {
                    "actionType": "confirmDialog",
                    "args": {
                        "title": "操作确认",
                        "msg": "是否退出系统？"
                    }},

                {
                    "actionType": "custom",
                    "script": "window.location.href = '/TeenStudy/login';window.localStorage.clear();window.sessionStorage.clear();\n //event.stopPropagation();"
                }

            ]
        },
    }}])
operation_button = Flex(justify='center', items=[
    ActionType.Dialog(
        label='修改信息',
        className='m-l',
        level=LevelEnum.primary,
        dialog=Dialog(title='修改信息',
                      size='lg',
                      body=[
                          Form(
                              title='',
                              api='put:/TeenStudy/api/change?user_id=${user_id}',
                              submitText='保存修改',
                              mode=DisplayModeEnum.horizontal,
                              labelAlign='right',
                              body=[
                                  InputText(label='性别', name='gender', value='${gender}', required=True,
                                            trimContents=True, clearable=True,
                                            showCounter=True, maxLength=3, visibleOn="${gender==null?false:true}",
                                            description='性别'),
                                  InputText(label='uid|nid', name='dxx_id', value='${dxx_id}', required=True,
                                            trimContents=True, clearable=True,
                                            showCounter=True, maxLength=24, visibleOn="${dxx_id==null?false:true}",
                                            description='大学习认证ID，不清楚请勿改动'),
                                  InputText(label='手机号', name='mobile', value='${mobile}', required=True,
                                            trimContents=True, clearable=True,
                                            showCounter=True, maxLength=24, visibleOn="${mobile==null?false:true}",
                                            description='手机号'),
                                  InputText(label='团支书ID', name='leader', value='${leader}',
                                            showCounter=True, maxLength=10, hiddenOn=True, trimContents=True,
                                            clearable=True,
                                            description='团支书ID，填写后团支书可操作提交功能，不清楚请勿改动'),
                                  InputText(label='openid', name='openid', value='${openid}', required=True,
                                            trimContents=True, clearable=True,
                                            showCounter=True, maxLength=64, visibleOn="${openid==null?false:true}",
                                            description='微信认证ID，不清楚请勿改动'),
                                  InputText(label='登录密码', name='Password', value='', type="input-password",
                                            trimContents=True, clearable=True,
                                            showCounter=True, maxLength=16, visibleOn="${password==null?false:true}",
                                            description='登录Web UI的密码'),
                                  InputText(label='学校类型', name='university_type', value='${university_type}',
                                            showCounter=True, maxLength=16, required=True, trimContents=True,
                                            clearable=True,
                                            visibleOn="${university_type==null?false:true}",
                                            description='学校类型，不清楚请勿改动'),
                                  InputText(label='学校ID', name='university_id', value='${university_id}',
                                            required=True, trimContents=True, clearable=True,
                                            showCounter=True, maxLength=24,
                                            visibleOn="${university_id==null?false:true}",
                                            description='学校ID，不清楚请勿改动'),
                                  InputText(label='学校名称', name='university', value='${university}', required=True,
                                            trimContents=True, clearable=True,
                                            showCounter=True, maxLength=20, visibleOn="${university==null?false:true}",
                                            description='学校名称'),
                                  InputText(label='学院ID', name='college_id', value='${college_id}', required=True,
                                            trimContents=True, clearable=True,
                                            showCounter=True, maxLength=24, visibleOn="${college_id==null?false:true}",
                                            description='学院ID'),
                                  InputText(label='学院名称', name='college', value='${college}',
                                            trimContents=True, clearable=True,
                                            showCounter=True, maxLength=24, visibleOn="${college==null?false:true}",
                                            description='学院名称'),
                                  InputText(label='团支部ID', name='organization_id', value='${organization_id}',
                                            required=True, trimContents=True, clearable=True,
                                            showCounter=True, maxLength=24,
                                            visibleOn="${organization_id==null?false:true}",
                                            description='团支部ID'),
                                  InputText(label='团支部名称', name='organization', value='${organization}',
                                            required=False, trimContents=True, clearable=True,
                                            showCounter=True, maxLength=36,
                                            visibleOn="${organization==null?false:true}",
                                            description='团支部名称'),
                                  InputText(label='token', name='token', value='${token}', required=True,
                                            trimContents=True, clearable=True,
                                            showCounter=True, visibleOn="${token==null?false:true}",
                                            description='提交大学习需要的token'),
                                  InputText(label='cookie', name='cookie', value='${cookie}', required=True,
                                            trimContents=True, clearable=True,
                                            showCounter=True, visibleOn="${cookie==null?false:true}",
                                            description='提交大学习需要的cookie')
                              ])
                      ])
    ),
    ActionType.Ajax(
        label="提交大学习",
        className='m-l',
        level=LevelEnum.primary,
        confirmText='是否提交最新一期青年大学习？',
        api='get:/TeenStudy/api/commit?user_id=${user_id}&area=${area}'
    ),
    Switch(name='auto_submit',
           value='${auto_submit}',
           tooltip='自动提交大学习开关',
           onText='自动开',
           offText='自动关',
           onEvent={
               'change': {
                   'actions': {
                       'actionType': 'ajax',
                       'args': {
                           'api': {
                               'url': '/TeenStudy/api/set_auto_submit',
                               'method': 'put'
                           },
                           'messages': {
                               'success': '自动提交已设置为${event.data.value==true?"开启":"关闭"}',
                               'failed': '修改失败！'
                           },
                           'status': '${event.data.value}',
                           'id': '${id}'
                       }
                   }
               }
           })
])

from_table = Service(
    title="",
    api={
        "method": "get",
        "url": "/TeenStudy/api/get_user",
        "headers": {
            "token": """${window.localStorage.getItem("token")}""",
        }
    },
    interval=12000,
    body=[
        operation_button, Divider(),
        Property(
            title='用户详细信息',
            column=2,
            items=[
                Property.Item(
                    label='用户ID',
                    content='${user_id}'
                ),
                Property.Item(
                    label='姓名',
                    content='${name}'
                ),
                Property.Item(
                    label='地区',
                    content='${area}'
                ),
                Property.Item(
                    label='学校',
                    content='${university}'
                ),
                Property.Item(
                    label='学院',
                    content='${college}'
                ),
                Property.Item(
                    label='团支部',
                    content='${organization}'
                ),
                Property.Item(
                    label='最新提交期数',
                    content='${catalogue}'
                ),
                Property.Item(
                    label='最新提交时间',
                    content='${commit_time}'
                ),
                Property.Item(
                    label='性别',
                    content='${gender}',
                    visibleOn="${gender==null?false:true}"
                ),
                Property.Item(
                    label='手机号|学号',
                    content='${mobile}',
                    visibleOn="${mobile==null?false:true}"
                ),
                Property.Item(
                    label='团支书ID',
                    content='${leader}',
                    visibleOn="${leader==null?false:true}"
                ),
                Property.Item(
                    label='Uid|Nid',
                    content='${dxx_id}',
                    visibleOn="${dxx_id==null?false:true}"
                ),
                Property.Item(
                    label='学校类型',
                    content='${university_type}',
                    visibleOn="${university_type==null?false:true}"
                ),
                Property.Item(
                    label='学校ID',
                    content='${university_id}',
                    visibleOn="${university_id==null?false:true}"
                ),
                Property.Item(
                    label='学院ID',
                    content='${college_id}',
                    visibleOn="${college_id==null?false:true}"
                ),
                Property.Item(
                    label='团支部ID',
                    content='${organization_id}',
                    visibleOn="${organization_id==null?false:true}"
                ), Property.Item(
                    label='openid',
                    content='${openid}',
                    visibleOn="${openid==null?false:true}"
                ), Property.Item(
                    label='token',
                    content='${token}',
                    visibleOn="${token==null?false:true}",
                    span=2
                ), Property.Item(
                    label='cookie',
                    content='${cookie}',
                    visibleOn="${cookie==null?false:true}",
                    span=2
                )
            ]
        )
    ]
)
"""提交记录模板"""
record_table = CRUD(mode='table',
                    title='',
                    syncLocation=False,
                    api='/TeenStudy/api/get_records?user_id=${user_id}',
                    type='crud',
                    headerToolbar=["bulkActions", "reload"],
                    itemActions=[],
                    footable=True,
                    columns=[
                        TableColumn(label='用户ID', name='user_id'),
                        TableColumn(label='姓名', name='name'),
                        TableColumn(label='提交地区', name='area'),
                        TableColumn(label='学校名称', name='university'),
                        TableColumn(label='学院名称', name='college'),
                        TableColumn(label='团支部', name='organization'),
                        TableColumn(label='提交期数', name='catalogue', searchable=True),
                        TableColumn(tppe="tpl", label='提交状态', tpl='${status===true?"成功":"失败"}', name="status",
                                    searchable=True),
                        TableColumn(type='tpl', tpl='${time|date:YYYY-MM-DD HH\\:mm\\:ss}',
                                    label='提交时间',
                                    name='time', sortable=True)
                    ])

answer_table = Service(
    title="",
    api={
        "method": "get",
        "url": "/TeenStudy/api/get_user",
        "headers": {
            "token": """${window.localStorage.getItem("token")}""",
        }
    },
    interval=60000,
    body=[CRUD(mode='table',
               title='',
               syncLocation=False,
               api='/TeenStudy/api/get_answers',
               type='crud',
               headerToolbar=["bulkActions", "reload"],
               itemActions=[ActionType.Ajax(tooltip='提交',
                                            label="提交",
                                            confirmText='是否提交青年大学习${catalogue}?',
                                            api='get:/TeenStudy/api/commit?user_id=${user_id}&area=${area}&catalogue=${catalogue}')],
               footable=True,
               columns=[
                   TableColumn(label='数据库ID', name='id'),
                   TableColumn(label='大学习ID', name='code'),
                   TableColumn(label='大学习期数', name='catalogue', searchable=True),
                   TableColumn(type='tpl', tpl='${url|truncate:20}', label='官方网址',
                               name='url',
                               popOver={'mode': 'dialog', 'title': '完整网址',
                                        'className': 'break-all',
                                        'body': {'type': 'tpl',
                                                 'tpl': '${url}'}}, copyable=True),
                   TableColumn(type='tpl', tpl='${end_url|truncate:20}', label='完成截图网址',
                               name='end_url',
                               popOver={'mode': 'dialog', 'title': '完整网址',
                                        'className': 'break-all',
                                        'body': {'type': 'tpl',
                                                 'tpl': '${end_url}'}}, copyable=True),
                   TableColumn(type='tpl', tpl='${answer|truncate:20}', label='答案',
                               name='answer',
                               popOver={'mode': 'dialog', 'title': '完整答案',
                                        'className': 'break-all',
                                        'body': {'type': 'tpl',
                                                 'tpl': '${answer}'}}),
                   TableColumn(type='tpl', tpl='${time|date:YYYY-MM-DD HH\\:mm\\:ss}',
                               label='更新时间',
                               name='time', sortable=True)
               ])])
page_detail = Page(title='', body=[logo, from_table])
home_page = PageSchema(url='/TeenStudy/home', label='首页', icon='fas fa-home', vendor="", isDefaultPage=True,
                       schema=page_detail)
home_app = App(brandName='TeenStudy',
               logo='https://img1.imgtp.com/2023/10/06/NChUNeiA.png',
               header=header,
               pages=[{
                   'children': [
                       home_page,
                       PageSchema(url="/TeenStudy/answer", label='大学习列表', icon='fas fa-book-open', vendor="",
                                  schema=Page(title='', body=[answer_table])),
                       PageSchema(url="/TeenStudy/records", label='提交记录', icon='fas fa-code-branch', vendor="",
                                  schema=Page(title='', body=[record_table]))
                   ]}],
               footer=Html(
                   html=f'<div class="p-2 text-center bg-blue-100">Copyright © 2022 - 2023 <a href="https://github.com/YouthLearning/TeenStudy" target="_blank" class="link-secondary">TeenStudy v.0.2.5</a> X<a target="_blank" href="https://github.com/baidu/amis" class="link-secondary" rel="noopener"> amis v.3.4.3</a></div>'))



from amis import Form, InputText, InputPassword, DisplayModeEnum, Horizontal, Remark, Html, Page, AmisAPI, Wrapper, \
    Switch

logo = Html(html=f'''
<p align="center">
    <a href="https://github.com/YouthLearning/TeenStudy/">
        <img src="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
         width="256" height="256" alt="TeenStudy">
    </a>
</p>
<h2 align="center">大学习自动提交</h2>
<div align="center">
    <a href="https://github.com/YouthLearning/TeenStudy/" target="_blank">
    Github仓库</a>
    <a href="https://jq.qq.com/?_wv=1027&k=NGFEwXyS" target="_blank">QQ反馈群</a>
    <a href="http://qm.qq.com/cgi-bin/qm/qr?_wv=1027&k=2PQucjirnkHyPjoS1Pkr-ai2aPGToBKm" target="_blank">QQ体验群</a>
</div>
<br>
<br>
''')
login_api = AmisAPI(
    url='/TeenStudy/api/login',
    method='post',
    adaptor='''
        if (payload.status == 0) {
            localStorage.setItem("token", payload.data.token);
            localStorage.setItem("user_id", payload.data.user_id);
            localStorage.setItem("role", payload.data.role);
            if(payload.data.role){
            window.location.href = '/TeenStudy/admin'
            }
            else{
            window.location.href = '/TeenStudy/home?user_id='+payload.data.user_id;}
        }
        return payload;
    '''
)

login_form = Form(api=login_api, title='', body=[
    InputText(name='user_id', label='用户ID', description='默认为用户QQ号'),
    InputPassword(name='password', label='密码',
                  description='管理员默认为admin，普通用户默认为QQ号'),
    Switch(name='role', label='身份组', onText='管理员', offText='用户', value=False,
           labelRemark=Remark(shape='circle', content='是否以管理员身份登录'))
], mode=DisplayModeEnum.horizontal, horizontal=Horizontal(left=3, right=9, offset=5), submitText="登录")
body = Wrapper(className='w-2/5 mx-auto my-0 m:w-full', body=login_form)
login_page = Page(title='', body=[logo, body])



import nonebot
from fastapi import FastAPI
from fastapi.responses import HTMLResponse
from nonebot import get_driver
from nonebot.log import logger

from . import api, pages, utils
from .pages.admin import admin_app
from .pages.home import home_app
from .pages.login import login_page

requestAdaptor = '''
requestAdaptor(api) {
    api.headers["token"] = localStorage.getItem("token");
    api.headers["role"] = localStorage.getItem("role");
    api.headers["user_id"] = localStorage.getItem("user_id");
    return api;
},
'''
responseAdaptor = '''
responseAdaptor(api, payload, query, request, response) {
    if (response.data.detail == '登录验证失败或已失效，请重新登录') {
        window.location.href = '/TeenStudy/login'
        window.localStorage.clear()
        window.sessionStorage.clear()
        window.alert('登录验证失败或已失效，请重新登录')
    }
    return payload
},
'''
DRIVER = get_driver()
icon_path = 'https://img1.imgtp.com/2023/10/06/NChUNeiA.png'


@DRIVER.on_startup
async def init_web():
    app: FastAPI = nonebot.get_app()
    logger.opt(colors=True).info(
        f'<u><y>[大学习提交 Web UI]</y></u><g>启用成功</g>，本机访问地址为:<m>http://127.0.0.1:{DRIVER.config.port}/TeenStudy/login</m>')
    app.include_router(api.BaseApiRouter)

    @app.get("/TeenStudy/login", response_class=HTMLResponse)
    async def login():
        return login_page.render(
            site_title='TeenStudy | 登录',
            site_icon=icon_path
        )

    @app.get('/TeenStudy/home', response_class=HTMLResponse)
    async def home():
        return home_app.render(
            site_title='TeenStudy 首页',
            site_icon=icon_path,
            requestAdaptor=requestAdaptor,
            responseAdaptor=responseAdaptor
        )

    @app.get("/TeenStudy/admin", response_class=HTMLResponse)
    async def admin():
        return admin_app.render(
            site_title='TeenStudy | 管理后台',
            site_icon=icon_path,
            requestAdaptor=requestAdaptor,
            responseAdaptor=responseAdaptor
        )



import asyncio
from typing import Union, Optional

from fastapi import APIRouter, Header
from fastapi.responses import StreamingResponse
from nonebot.log import logger, default_filter, default_format

from ...utils.path import getConfig

CONFIG = getConfig()
SECRET_KEY = CONFIG["KEY"]
info_logs = []
debug_logs = []


def record_info_log(message: str):
    info_logs.append(message)
    if len(info_logs) > 500:
        info_logs.pop(0)


def record_debug_log(message: str):
    # 过滤一些无用日志
    if not any(w in message for w in {'Checking for matchers', 'Running PreProcessors', 'OneBot V11 | Calling API'}):
        debug_logs.append(message)
        if len(debug_logs) > 300:
            debug_logs.pop(0)


logger.add(record_info_log, level='INFO', colorize=True, filter=default_filter, format=default_format)
logger.add(record_debug_log, level='DEBUG', colorize=True, filter=default_filter, format=default_format)

route = APIRouter()


@route.get('/log')
async def get_log(token: Optional[str] = Header(...), level: str = 'info', num: Union[int, str] = 100):
    if token != SECRET_KEY[:16]:
        return '非法请求'
    show_logs = info_logs[-(num or 1):] if level == 'info' else debug_logs[-(num or 1):]

    async def streaming_logs():
        for log in show_logs:
            yield log
            await asyncio.sleep(0.02)

    return StreamingResponse(streaming_logs())



from amis import InputText, Form, DisplayModeEnum, Alert, LevelEnum, Select, PageSchema
from amis import Page, ActionType, Dialog, Card, Tpl, Switch, CardsCRUD

detail_form = Form(
    title='',
    api='put:/TeenStudy/api/change?user_id=${user_id}',
    submitText='保存修改',
    mode=DisplayModeEnum.horizontal,
    labelAlign='right',
    body=[
        Select(
            label="通知群聊",
            name="group_id",
            description="大学习提醒群号",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='${group_id}',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        InputText(label='性别', name='gender', value='${gender}', required=True,
                  trimContents=True, clearable=True,
                  showCounter=True, maxLength=3, visibleOn="${gender==null?false:true}",
                  description='性别'),
        InputText(label='uid|nid', name='dxx_id', value='${dxx_id}', required=True,
                  trimContents=True, clearable=True,
                  showCounter=True, maxLength=24, visibleOn="${dxx_id==null?false:true}",
                  description='大学习认证ID，不清楚请勿改动'),
        InputText(label='手机号|学号', name='mobile', value='${mobile}', required=False,
                  trimContents=True, clearable=True,
                  showCounter=True, maxLength=24, visibleOn="${mobile==null?false:true}",
                  description='手机号'),
        InputText(label='团支书ID', name='leader', value='${leader}',
                  showCounter=True, maxLength=10, hiddenOn=True, trimContents=True,
                  clearable=True,
                  description='团支书ID，填写后团支书可操作提交功能，不清楚请勿改动'),
        InputText(label='openid', name='openid', value='${openid}', required=True,
                  trimContents=True, clearable=True,
                  showCounter=True, maxLength=64, visibleOn="${openid==null?false:true}",
                  description='微信认证ID，不清楚请勿改动'),
        InputText(label='登录密码', name='Password', value='', type="input-password",
                  trimContents=True, clearable=True,
                  showCounter=True, maxLength=16, visibleOn="${password==null?false:true}",
                  description='登录Web UI的密码'),
        InputText(label='学校类型', name='university_type', value='${university_type}',
                  showCounter=True, maxLength=16, required=True, trimContents=True,
                  clearable=True,
                  visibleOn="${university_type==null?false:true}",
                  description='学校类型，不清楚请勿改动'),
        InputText(label='学校ID', name='university_id', value='${university_id}',
                  required=True, trimContents=True, clearable=True,
                  showCounter=True, maxLength=24,
                  visibleOn="${university_id==null?false:true}",
                  description='学校ID，不清楚请勿改动'),
        InputText(label='学校名称', name='university', value='${university}', required=True,
                  trimContents=True, clearable=True,
                  showCounter=True, maxLength=20, visibleOn="${university==null?false:true}",
                  description='学校名称'),
        InputText(label='学院ID', name='college_id', value='${college_id}', required=False,
                  trimContents=True, clearable=True,
                  showCounter=True, maxLength=24, visibleOn="${college_id==null?false:true}",
                  description='学院ID'),
        InputText(label='学院名称', name='college', value='${college}',
                  trimContents=True, clearable=True,
                  showCounter=True, maxLength=24, visibleOn="${college==null?false:true}",
                  description='学院名称'),
        InputText(label='团支部ID', name='organization_id', value='${organization_id}',
                  required=True, trimContents=True, clearable=True,
                  showCounter=True, maxLength=24,
                  visibleOn="${organization_id==null?false:true}",
                  description='团支部ID'),
        InputText(label='团支部名称', name='organization', value='${organization}',
                  required=False, trimContents=True, clearable=True,
                  showCounter=True, maxLength=36,
                  visibleOn="${organization==null?false:true}",
                  description='团支部名称'),
        InputText(label='token', name='token', value='${token}', required=True,
                  trimContents=True, clearable=True,
                  showCounter=True, visibleOn="${token==null?false:true}",
                  description='提交大学习需要的token'),
        InputText(label='cookie', name='cookie', value='${cookie}', required=True,
                  trimContents=True, clearable=True,
                  showCounter=True, visibleOn="${cookie==null?false:true}",
                  description='提交大学习需要的cookie')
    ])
detail_button = ActionType.Dialog(label='信息',
                                  tooltip='查看|修改信息',
                                  size='lg',
                                  icon='fas fa-user-tag text-primary',
                                  dialog=Dialog(title='${name}的详细信息', size='lg', body=[detail_form]))
card = Card(
    header=Card.Header(title='$name',
                       subTitle='$user_id',
                       description='$catalogue',
                       avatarText='${area}',
                       avatarTextClassName='overflow-hidden'),
    actions=[detail_button, ActionType.Ajax(
        label="提交",
        tooltip='提交大学习',
        icon='fas fa-check text-success',
        confirmText='是否提交最新一期青年大学习？',
        api='get:/TeenStudy/api/commit?user_id=${user_id}&area=${area}'
    ), ActionType.Ajax(
        tooltip='删除',
        label="删除",
        icon='fas fa-trash-can text-danger',
        confirmText='删除该用户',
        api='delete:/TeenStudy/api/delete_member?user_id=${user_id}'
    ), ],
    toolbar=[
        Tpl(tpl='$area', className='label label-warning', hiddenOn=True),
        Switch(name='auto_submit',
               value='${auto_submit}',
               tooltip='自动提交大学习开关',
               onText='开启',
               offText='关闭',
               onEvent={
                   'change': {
                       'actions': {
                           'actionType': 'ajax',
                           'args': {
                               'api': {
                                   'url': '/TeenStudy/api/set_auto_submit',
                                   'method': 'put'
                               },
                               'messages': {
                                   'success': '自动提交已设置为${event.data.value==true?"开启":"关闭"}',
                                   'failed': '修改失败！'
                               },
                               'status': '${event.data.value}',
                               'id': '${id}'
                           }
                       }
                   }
               })
    ])
"""成员卡片面板"""
cards_curd = CardsCRUD(mode='cards',
                       title='',
                       syncLocation=False,
                       name="member",
                       fetchFailed="数据初始化！",
                       api='get:/TeenStudy/api/get_members',
                       loadDataOnce=True,
                       interval=180000,
                       source='${rows | filter:user_id:keywords_user_id | filter:name:keywords_name|filter:area:keywords_area|filter:university:keywords_university|filter:college:keywords_college|filter:organization:keywords_organization}',
                       filter={
                           'body': [
                               InputText(name='keywords_user_id', label='用户ID',
                                         trimContents=True, clearable=True,
                                         submitOnChange=True),
                               InputText(name='keywords_name', label='用户姓名',
                                         trimContents=True, clearable=True,
                                         submitOnChange=True),
                               InputText(name='keywords_area', label='地区',
                                         trimContents=True, clearable=True,
                                         submitOnChange=True),
                               InputText(name='keywords_university', label='学校',
                                         trimContents=True, clearable=True,
                                         submitOnChange=True),
                               InputText(name='keywords_college', label='学院',
                                         trimContents=True, clearable=True,
                                         submitOnChange=True),
                               InputText(name='keywords_organization', label='团支部',
                                         trimContents=True, clearable=True,
                                         submitOnChange=True),
                           ]
                       },
                       perPage=16,
                       autoJumpToTopOnPagerChange=True,
                       placeholder='暂无大学习用户',
                       footerToolbar=['switch-per-page', 'pagination'],
                       columnsCount=4,
                       card=card)

list_page = PageSchema(url='/TeenStudy/list', icon='fas fa-list-ul', label='成员列表',
                       schema=Page(title='成员列表', body=[cards_curd]))

"""湖北添加成员面板"""
hubei_table = Form(
    title="添加青春湖北用户",
    submitText="添加",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/add",
    resetAfterSubmit=True,
    body=[
        Select(
            label="群聊",
            name="group_id",
            description="需要添加的群组",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        Select(
            label="用户ID",
            name="user_id",
            description="需要添加的用户ID",
            checkAll=False,
            source="get:/TeenStudy/api/get_member_list?group_id=${group_id}",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
            hiddenOn="${group_id==''?true:false}"
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="湖北",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="对应青春湖北个人信息页 您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="用户编号",
            description="对应青春湖北个人信息页 用户编号",
            name="dxx_id",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=9
        ),
        InputText(
            label="学校",
            description="对应青春湖北填写信息页 高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="对应青春湖北填写信息页 院系",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="对应青春湖北填写信息页 选择组织",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        )

    ]
)
"""江西添加成员面板"""
jiangxi_table = Form(
    title="添加江西共青团用户",
    submitText="添加",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/jiangxi/add",
    resetAfterSubmit=True,
    body=[
        Select(
            label="群聊",
            name="group_id",
            description="需要添加的群组",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        Select(
            label="用户ID",
            name="user_id",
            description="需要添加的用户ID",
            checkAll=False,
            source="get:/TeenStudy/api/get_member_list?group_id=${group_id}",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
            hiddenOn="this.group_id==''?true:false"
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="江西",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="url",
            description="点进江西共青团选择青年大学习H5，进去后点右上角三个点，复制链接填入即可 链接格式：http://www.jxqingtuan.cn/html/?accessToken=xxxxxx&openid=xxxxxxxxxxxx&requestType=http#/",
            name="url",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=512
        )

    ]
)

"""安徽添加成员面板"""
anhui_table = Form(
    title="添加安徽共青团用户",
    submitText="添加",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/anhui/add",
    resetAfterSubmit=True,
    body=[
        Select(
            label="群聊",
            name="group_id",
            description="需要添加的群组",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        Select(
            label="用户ID",
            name="user_id",
            description="需要添加的用户ID",
            checkAll=False,
            source="get:/TeenStudy/api/get_member_list?group_id=${group_id}",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
            hiddenOn="${group_id==''?true:false}"
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="安徽",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="url",
            description="个人信息修改页，点右上角分享，复制链接填入即可 链接格式：http://dxx.ahyouth.org.cn/modify/?tk=您的token值",
            name="url",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=128
        )

    ]
)
"""四川添加成员面板"""
sichuan_table = Form(
    title="添加天府新青年用户",
    submitText="添加",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/sichuan/add",
    resetAfterSubmit=True,
    body=[
        Alert(level=LevelEnum.info,
              className='white-space-pre-wrap',
              body=(
                  "该地区需要自行抓包填入\ntoken值在https://dxx.scyol.com/api/wechat/login 响应里\n其余信息在 https://dxx.scyol.com/api/student/showStudyStageOrg?id=xxxxxx&stageId=xx 响应里")),
        Select(
            label="群聊",
            name="group_id",
            description="需要添加的群组",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        Select(
            label="用户ID",
            name="user_id",
            description="需要添加的用户ID",
            checkAll=False,
            source="get:/TeenStudy/api/get_member_list?group_id=${group_id}",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
            hiddenOn="${group_id==''?true:false}"
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="四川",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="对应抓包内容 name",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="token",
            description="自行抓包获取，在：https://dxx.scyol.com/api/wechat/login 链接的响应内容里",
            name="token",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="手机号",
            description="自行抓包获取，对应tel",
            name="mobile",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="整体组织ID",
            description="自行抓包获取，对应org",
            name="org",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="组织ID",
            description="自行抓包获取，对应lastOrg",
            name="lastOrg",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="团支部名称",
            description="自行抓包获取，对应 orgName",
            name="orgName",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ), InputText(
            label="组织全称",
            description="自行抓包获取，对应allOrgName",
            name="allOrgName",
            inline=False,
            required=True,
            value="",
            clearable=True,
        )

    ]
)
"""山东添加成员面板"""
shandong_table = Form(
    title="添加青春山东用户",
    sunmitText="添加",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/shandong/add",
    resetAfterSubmit=True,
    body=[
        Select(
            label="群聊",
            name="group_id",
            description="需要添加的群组",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        Select(
            label="用户ID",
            name="user_id",
            description="需要添加的用户ID",
            checkAll=False,
            source="get:/TeenStudy/api/get_member_list?group_id=${group_id}",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
            hiddenOn="${group_id==''?true:false}"
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="山东",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="对应青春山东个人信息页 您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="cookie",
            description="自行抓包获取，结构为：JSESSIONID=1873FXXXXXXXX5DFCBF1CC13703",
            name="cookie",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="openid",
            description="自行抓包获取，结构为：ohz9xxxxxxxxxxxxlF0Io0uCnM",
            name="openid",
            inline=False,
            required=True,
            value="",
            clearable=True,
        )

    ]
)
"""重庆添加成员面板"""
chongqing_table = Form(
    title="添加重庆共青团用户",
    sunmitText="添加",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/chongqing/add",
    resetAfterSubmit=True,
    body=[
        Select(
            label="群聊",
            name="group_id",
            description="需要添加的群组",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        Select(
            label="用户ID",
            name="user_id",
            description="需要添加的用户ID",
            checkAll=False,
            source="get:/TeenStudy/api/get_member_list?group_id=${group_id}",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
            hiddenOn="${group_id==''?true:false}"
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="重庆",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="对应重庆共青团个人信息页 您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="openid",
            description="自行抓包获取，结构为: ohz9xxxxxxxxxxxxlF0Io0uCnM",
            name="openid",
            inline=False,
            required=True,
            value="",
            clearable=True,
        )

    ]
)
"""吉林添加成员面板"""
jilin_table = Form(
    title="添加吉青飞扬用户",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/jilin/add",
    redirect="/TeenStudy/login",
    body=[
        Select(
            label="群聊",
            name="group_id",
            description="需要添加的群组",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        Select(
            label="用户ID",
            name="user_id",
            description="需要添加的用户ID",
            checkAll=False,
            source="get:/TeenStudy/api/get_member_list?group_id=${group_id}",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
            hiddenOn="${group_id==''?true:false}"
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="吉林",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="openid",
            description="自行抓包获取，结构为: ohz9xxxxxxxxxxxxlF0Io0uCnM",
            name="openid",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="学校",
            description="你就读的高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="学院名称",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="团支部|班级，没有可不填",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        )

    ]
)
"""广东地区添加用户"""
guangdong_table = Form(
    title="添加广东共青团用户",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/guangdong/add",
    redirect="/TeenStudy/login",
    body=[
        Alert(level=LevelEnum.info,
              className='white-space-pre-wrap',
              body=(
                  "链接获取方式:\n12355青春之声公众号\n智慧团建-认证资料-生成电子团员证，点击最下方生成按钮。\n在团员证页面复制链接 应为：https://tuan.12355.net/wechat/view/information/member_certification_generated.html?memberId=xxxxxx&showMemberAdditionNames=&showMemberRewardIds=&isShowAllFee=true \n其中xxxxxx即为mid")),
        Select(
            label="群聊",
            name="group_id",
            description="需要添加的群组",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        Select(
            label="用户ID",
            name="user_id",
            description="需要添加的用户ID",
            checkAll=False,
            source="get:/TeenStudy/api/get_member_list?group_id=${group_id}",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
            hiddenOn="${group_id==''?true:false}"
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="广东",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="url",
            description="链接格式：https://tuan.12355.net/wechat/view/information/member_certification_generated.html?memberId=xxxxxx&showMemberAdditionNames=&showMemberRewardIds=&isShowAllFee=true",
            name="url",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=512
        ),
        InputText(
            label="学校",
            description="你就读的高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="学院名称",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="团支部|班级，没有可不填",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        )]
)
"""北京地区添加用户面板"""
beijing_table = Form(
    title="添加北京共青团用户",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/beijing/add",
    redirect="/TeenStudy/login",
    body=[
        Select(
            label="群聊",
            name="group_id",
            description="需要添加的群组",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        Select(
            label="用户ID",
            name="user_id",
            description="需要添加的用户ID",
            checkAll=False,
            source="get:/TeenStudy/api/get_member_list?group_id=${group_id}",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
            hiddenOn="${group_id==''?true:false}"
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="北京",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ), InputText(
            label="大学习ID",
            description="名字后面括号内的数字",
            name="dxx_id",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="学校",
            description="你就读的高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="学院名称",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="团支部|班级，没有可不填",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部ID",
            description="支部后面括号内的数字",
            name="organization_id",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="账号",
            description="登录北京共青团的账号",
            name="cookie",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ), InputText(
            label="密码",
            description="登陆北京共青团的密码",
            name="token",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        )
    ]
)
"""天津地区添加用户"""
tianjin_table = Form(
    title="添加津彩青春用户",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/tianjin/add",
    redirect="/TeenStudy/login",
    body=[
        Select(
            label="群聊",
            name="group_id",
            description="需要添加的群组",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        Select(
            label="用户ID",
            name="user_id",
            description="需要添加的用户ID",
            checkAll=False,
            source="get:/TeenStudy/api/get_member_list?group_id=${group_id}",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
            hiddenOn="${group_id==''?true:false}"
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="天津",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="学校",
            description="你就读的高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="学院名称",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="团支部|班级，没有可不填",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="cookie",
            description="自行抓包获取，结构为：JSESSIONID=1873FXXXXXXXX5DFCBF1CC13703",
            name="cookie",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
    ]
)
"""三秦青年青年添加用户"""
shanxi_table = Form(
    title="添加三秦青年用户",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/ShanXi/add",
    redirect="/TeenStudy/login",
    body=[
        Select(
            label="群聊",
            name="group_id",
            description="需要添加的群组",
            checkAll=False,
            source="get:/TeenStudy/api/get_group_list",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
        ),
        Select(
            label="用户ID",
            name="user_id",
            description="需要添加的用户ID",
            checkAll=False,
            source="get:/TeenStudy/api/get_member_list?group_id=${group_id}",
            value='',
            multiple=False,
            required=True,
            searchable=True,
            joinValues=False,
            extractValue=True,
            statistics=True,
            hiddenOn="${group_id==''?true:false}"
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="陕西",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="学校",
            description="你就读的高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="学院名称",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="团支部|班级，没有可不填",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="token",
            description="自行抓包获取",
            name="token",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
    ]
)
hubei_page = PageSchema(url='/TeenStudy/add/hubei', icon='far fa-edit', vendor="", label='青春湖北',
                        schema=Page(title='青春湖北', body=[hubei_table]))
jiangxi_page = PageSchema(url='/TeenStudy/add/jiangxi', icon='far fa-edit', vendor="", label='江西共青团',
                          schema=Page(title='江西共青团', body=[jiangxi_table]))
anhui_page = PageSchema(url='/TeenStudy/add/anhui', icon='far fa-edit', vendor="", label='安徽共青团',
                        schema=Page(title='安徽共青团', body=[anhui_table]))
sichuan_page = PageSchema(url='/TeenStudy/add/sichuan', icon='far fa-edit', vendor="", label='天府新青年',
                          schema=Page(title='天府新青年', body=[sichuan_table]))
shandong_page = PageSchema(url='/TeenStudy/add/shandong', icon='far fa-edit', vendor="", label='青春山东',
                           schema=Page(title='青春山东', body=[shandong_table]))
chongqing_page = PageSchema(url='/TeenStudy/add/chongqing', icon='far fa-edit', vendor="", label='重庆共青团',
                            schema=Page(title='重庆共青团', body=[chongqing_table]))
jilin_page = PageSchema(url='/TeenStudy/add/jilin', icon='far fa-edit', vendor="", label='吉青飞扬',
                        schema=Page(title='吉青飞扬', body=[jilin_table]))
guangdong_page = PageSchema(url='/TeenStudy/add/guangdong', icon='far fa-edit', vendor="", label='广东共青团',
                            schema=Page(title='广东共青团', body=[guangdong_table]))
beijing_page = PageSchema(url='/TeenStudy/add/beijing', icon='far fa-edit', vendor="", label='北京共青团',
                          schema=Page(title='北京共青团', body=[beijing_table]))
tianjin_page = PageSchema(url='/TeenStudy/add/tianjin', icon='far fa-edit', vendor="", label='津彩青春',
                          schema=Page(title='津彩青春', body=[tianjin_table]))
shanxi_page = PageSchema(url='/TeenStudy/add/shanxi', icon='far fa-edit', vendor="", label='三秦青年',
                          schema=Page(title='三秦青年', body=[shanxi_table]))
areaPage = [list_page,
            hubei_page, jiangxi_page, anhui_page,
            sichuan_page, shandong_page, chongqing_page, jilin_page, guangdong_page, beijing_page,
            tianjin_page,shanxi_page
            ]



import datetime
from typing import Union

from nonebot.adapters.onebot.v11 import Bot, Message, MessageEvent, NotifyEvent
from nonebot.params import CommandArg

from ..models.accuont import User
from ..models.dxx import PushList


async def must_group(bot: Bot, event: Union[MessageEvent, NotifyEvent]) -> bool:
    """
    必须是群消息才响应
    :param bot: 机器人
    :param event: 事件
    :return: 返回True或False
    """
    if isinstance(event, MessageEvent):
        if event.message_type == "group":
            self_id = int(bot.self_id)
            group_id = event.group_id
            if await PushList.filter(group_id=group_id, status=True, self_id=self_id).count():
                return True

        else:
            return False
    else:
        try:
            group_id = event.group_id
        except AttributeError:
            return False
        self_id = int(bot.self_id)
        if await PushList.filter(group_id=group_id, status=True, self_id=self_id).count():
            return True
        return False


async def must_command(order: Message = CommandArg()) -> bool:
    """
    限制指令后面不能加内容才生效
    :param order: 指令后面的内容
    :return: 返回True或False
    """
    if order:
        return False
    else:
        return True


async def must_leader(bot: Bot, event: MessageEvent) -> bool:
    """
    只有团支书发送才生效
    :param bot: 机器人id
    :param event: 消息事件
    :return:
    """
    if event.message_type == "group":
        self_id = int(bot.self_id)
        group_id = event.group_id
        user_id = event.user_id
        if await User.filter(leader=user_id, group_id=group_id).count():
            return True
    else:
        return False


async def check_poke(event: NotifyEvent) -> bool:
    """
    判断是否为戳一戳消息通知
    :param event: 通知事件
    :return: 返回True或False
    """
    if event.sub_type in ["poke"]:
        return True
    else:
        return False




import asyncio
import json
import random
import secrets
import string
import time

from bs4 import BeautifulSoup
from httpx import AsyncClient
from nonebot import logger, require, get_bot, get_driver
from nonebot.adapters.onebot.v11 import Bot, MessageSegment

from .path import getConfig
from .utils import get_login_qrcode
from ..models.accuont import AddUser, User
from ..models.dxx import Answer, Area, JiangXiDxx, ShanDongDxx, ShanXiDxx

scheduler = require('nonebot_plugin_apscheduler').scheduler
super_id = get_driver().config.superusers  # 超管id
headers = {
    "Host": "h5.cyol.com",
    "Connection": "keep-alive",
    "Accept": "application/json, text/javascript, */*; q=0.01",
    "User-Agent": "Mozilla/5.0 (Linux; Android 10; PACM00 Build/QP1A.190711.020; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3164 MMWEBSDK/20211001 Mobile Safari/537.36 MMWEBID/556 MicroMessenger/8.0.16.2040(0x28001056) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
    "Origin": "http://h5.cyol.com",
    "X-Requested-With": "com.tencent.mm",
    "Sec-Fetch-Site": "cross-site",
    "Sec-Fetch-Mode": "cors",
    "Sec-Fetch-Dest": "empty",
    "Accept-Encoding": "gzip, deflate",
    "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
}


async def crawl_answer(url: str) -> dict:
    """
    获取青年大学习的期数，答案和完成截图链接
    :param url: 青年大学习的地址
    :return:
    """
    async with AsyncClient(headers=headers, max_redirects=5) as client:
        response = await client.get(url=url, timeout=10)
    response.encoding = response.charset_encoding
    soup = BeautifulSoup(response.text, 'lxml')
    title: str = soup.find('title').text[7:].strip()
    start_div: int = response.text.find('<div class="section0 topindex">')
    end_div: int = response.text.find('<script type="text/javascript" src="js/index.js')
    soup = BeautifulSoup(response.text[start_div:end_div], 'lxml')
    answer: dict = {"knowledgeCard": [], "exercise": []}
    option: str = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
    template: str = "{num}. {options}"
    for item in soup.select('body [class^="section"]'):
        topicId: int = int(item.get("class")[0][7:])
        temp: list = []
        for item2 in item.select("div"):
            if item2.get("data-a"):
                temp.append(item2.get("data-a"))
        if len(temp) == 0:
            continue
        if len(temp) > 4:
            temp = temp[:int(len(temp) / 2)]
        options: str = ""
        for i, v in enumerate(temp):
            if v == "1":
                options += option[i]
        if topicId < 4:
            answer["knowledgeCard"].append(
                template.format(num=len(answer["knowledgeCard"]) + 1, options=options) + "\n")
        else:
            answer["exercise"].append(template.format(num=len(answer["exercise"]) + 1, options=options) + "\n")
    try:
        end_url: str = url.replace('m.html', 'images/end.jpg')
    except IndexError:
        end_url: str = url[:-6] + 'images/end.jpg'
    return {
        "end_url": end_url,
        "catalogue": title,
        "answer": f'知识卡片：\n{"".join(answer["knowledgeCard"])}\n课后习题：\n{"".join(answer["exercise"])}'
    }


async def update_answer():
    logger.opt(colors=True).info("<u><y>[大学习数据库]</y></u><g>➤➤➤➤➤检查答案数据✔✔✔✔✔</g>")
    resp_url = 'https://h5.cyol.com/special/weixin/sign.json'
    async with AsyncClient(headers=headers) as client:
        response = await client.get(url=resp_url, timeout=10)
    response.encoding = response.charset_encoding
    result = response.json()
    code_result = list(result)[1:]
    for code in code_result:
        if await Answer.filter(code=code).count():
            continue
        else:
            try:
                url = result[code]["url"].replace("index.html", "m.html").replace("http://", "https://")
                data = await crawl_answer(url=url)
                end_url = data["end_url"]
                answer = data["answer"]
                catalogue = data["catalogue"]
                async with AsyncClient(headers=headers) as client:
                    end_jpg = await client.get(end_url, timeout=10)
                cover = end_jpg.content
                await Answer.create(
                    time=time.time(),
                    code=code,
                    catalogue=catalogue,
                    url=url,
                    end_url=end_url,
                    answer=answer,
                    cover=cover
                )
                logger.opt(colors=True).success(f"<u><y>青年大学习</y></u> <m>{catalogue}</m> <g>更新成功!</g>")
            except Exception as e:
                logger.info(code)
                logger.error(e)
    logger.opt(colors=True).success("<u><y>[大学习数据库]</y></u><g>➤➤➤➤➤答案数据更新完成✔✔✔✔✔</g>")


async def dxxInfo(url: str) -> dict:
    result = await Answer.filter(url=url.replace("index.html", "m.html").replace("http://", "https://")).values(
        "catalogue", "url", "code")
    if result:
        return {
            "status": True,
            "catalogue": result[0]["catalogue"],
            "url": url,
            "code": result[0]["code"]
        }
    return {
        "status": False
    }


async def update_shanxi():
    url = f"https://api.sxgqt.org.cn/h5sxapiv2/study/studyLink"
    headers.update({
        "Host": "api.sxgqt.org.cn",
        "accept": "application/json",
        "x-requested-with": "XMLHttpRequest",
        "user-agent": "Mozilla/5.0 (Linux; Android 13; 23049RAD8C Build/TKQ1.221114.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/111.0.5563.116 Mobile Safari/537.36 XWEB/5317 MMWEBSDK/20230701 MMWEBID/6170 MicroMessenger/8.0.40.2420(0x28002837) WeChat/arm64 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
        "version": "H5_3.2.0",
        "origin": "https://h5.sxgqt.org.cn"
    })
    try:
        async with AsyncClient(headers=headers) as client:
            response = await client.get(url=url)
            response.encoding = response.charset_encoding
            if response.json().get('code', -1) == 0:
                newList = response.json()["data"]["new"]
                dxxResult = await dxxInfo(
                    newList.get("url").replace("index.html", "m.html").replace("http://", "https://"))
                if dxxResult["status"]:
                    await ShanXiDxx.create(
                        time=time.time(),
                        code=newList.get("id", -2),
                        name=dxxResult["catalogue"],
                        url=newList.get("url", "https://h5.cyol.com/special/weixin/sign.json")
                    )
                else:
                    await ShanXiDxx.create(
                        time=time.time(),
                        code=newList.get("id", -2),
                        name=newList["name"],
                        url=newList.get("url", "https://h5.cyol.com/special/weixin/sign.json")
                    )
                dxxList = response.json()["data"]["old"]
                for item in dxxList:
                    if await ShanXiDxx.filter(code=item.get("id", -1)).count():
                        continue
                    dxxResult = await dxxInfo(
                        item.get("url").replace("index.html", "m.html").replace("http://", "https://"))
                    if dxxResult["status"]:
                        await ShanXiDxx.create(
                            time=time.time(),
                            code=item.get("id", -2),
                            name=dxxResult["catalogue"],
                            url=item.get("url", "https://h5.cyol.com/special/weixin/sign.json")
                        )
                    else:
                        await ShanXiDxx.create(
                            time=time.time(),
                            code=item.get("id", -2),
                            name=item["name"],
                            url=item.get("url", "https://h5.cyol.com/special/weixin/sign.json")
                        )
    except Exception as e:
        logger.error(e)


async def update_jiangxi():
    url = f"http://www.jxqingtuan.cn/pub/pub/vol/volClass/index?userId={random.randint(4363000, 4364000)}&&page=1&pageSize=100"
    headers.update({
        'Cookie': 'JSESSIONID=' + secrets.token_urlsafe(40),
        'Host': 'www.jxqingtuan.cn',
        'Origin': 'http://www.jxqingtuan.cn',
        'Referer': 'http://www.jxqingtuan.cn/html/h5_index.html?&accessToken=' + ''.join(
            random.sample(string.ascii_letters + string.digits, 28)),
    })
    try:
        async with AsyncClient(headers=headers) as client:
            response = await client.get(url=url)
            response.encoding = response.charset_encoding
            if response.json().get('code', -1) == 0:
                dxxList = response.json().get("list", [])
                for item in dxxList:
                    if await JiangXiDxx.filter(code=item.get("id", -1)).count():
                        continue
                    dxxResult = await dxxInfo(
                        item.get("url").replace("index.html", "m.html").replace("http://", "https://"))
                    if dxxResult["status"]:
                        await JiangXiDxx.create(
                            time=time.time(),
                            score=item.get("score", 0),
                            addtime=item.get("addtime", "1970-01-01 00:00:00"),
                            endtime=item.get("endtime", "1970-01-01 00:00:00"),
                            code=item.get("id", -2),
                            starttime=item.get("starttime", "1970-01-01 00:00:00"),
                            title=dxxResult["catalogue"],
                            url=item.get("url", "https://h5.cyol.com/special/weixin/sign.json")
                        )
                    else:
                        await JiangXiDxx.create(
                            time=time.time(),
                            score=item.get("score", 0),
                            addtime=item.get("addtime", "1970-01-01 00:00:00"),
                            endtime=item.get("endtime", "1970-01-01 00:00:00"),
                            code=item.get("id", -2),
                            starttime=item.get("starttime", "1970-01-01 00:00:00"),
                            title=item.get("title", "青年大学习"),
                            url=item.get("url", "https://h5.cyol.com/special/weixin/sign.json")
                        )
    except Exception as e:
        logger.error(e)


async def update_shandong():
    headers.update({
        "Host": "qndxx.youth54.cn",
        "Connection": "keep-alive",
        "Accept": "*/*",
        "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220213.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3234 MMWEBSDK/20210902 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.15.2020(0x28000F30) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
        "X-Requested-With": "XMLHttpRequest",
        "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
        "Origin": "http://qndxx.youth54.cn",
        "Referer": "http://qndxx.youth54.cn/SmartLA/dxx.w?method=pageSdtwdt",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
    })
    new_version_url = f'http://qndxx.youth54.cn/SmartLA/dxxjfgl.w?method=getNewestVersionInfo'
    try:
        async with AsyncClient(headers=headers) as client:
            version_response = await client.post(url=new_version_url)
            version_response.encoding = version_response.charset_encoding
            content = version_response.json()
            if content["errcode"] == "0":
                if not await ShanDongDxx.filter(url=content["dxxurl"]).count():
                    dxxResult = await dxxInfo(url=content["dxxurl"])
                    if dxxResult["status"]:
                        await ShanDongDxx.create(
                            time=time.time(),
                            fbsj=content["tjsj"],
                            version=content["version"],
                            title=dxxResult["catalogue"],
                            url=content["dxxurl"]
                        )
                    else:
                        await ShanDongDxx.create(
                            time=time.time(),
                            fbsj=content["tjsj"],
                            version=content["version"],
                            title=content["versionname"],
                            url=content["dxxurl"]
                        )
            dxxListUrl = "http://qndxx.youth54.cn/SmartLA/dxxjfgl.w?method=getPastCompilationList"
            async with AsyncClient(headers=headers) as client:
                response = await client.post(url=dxxListUrl)
                response.encoding = response.charset_encoding
                content = response.json()
                if content["errcode"] == "0":
                    for item in content["vds"]:
                        url = f"http://qndxx.youth54.cn/SmartLA/dxxjfgl.w?method=getVersionUnderCompilation&hjqc={item['hjqc']}"
                        response = await client.post(url=url)
                        response.encoding = response.charset_encoding
                        content = response.json()
                        if content["errcode"] == "0":
                            for item2 in content["vds"]:
                                if not await ShanDongDxx.filter(
                                        url=item2["url"].replace("index.html", "m.html").replace("http://",
                                                                                                 "https://")).count():
                                    dxxResult = await dxxInfo(url=item2["url"])
                                    if dxxResult["status"]:
                                        await ShanDongDxx.create(
                                            time=time.time(),
                                            fbsj=item2["fbsj"],
                                            version=item2["version"],
                                            title=dxxResult["catalogue"],
                                            url=item2["url"]
                                        )
                                    else:
                                        await ShanDongDxx.create(
                                            time=time.time(),
                                            fbsj=item2["fbsj"],
                                            version=item2["version"],
                                            title=item2["mc"],
                                            url=item2["url"]
                                        )
    except Exception as e:
        logger.error(e)


@scheduler.scheduled_job('cron', day_of_week='0-6', hour="0-23", minute="*/15", id='update_data',
                         timezone="Asia/Shanghai")
async def update_data():
    try:
        bot: Bot = get_bot()
    except ValueError as e:
        return
    try:
        resp_url = 'https://h5.cyol.com/special/weixin/sign.json'
        async with AsyncClient(headers=headers) as client:
            response = await client.get(url=resp_url, timeout=10)
        response.encoding = response.charset_encoding
        result = json.loads(response.text)
        code_result = list(result)[1:]
        for code in code_result:
            if await Answer.filter(code=code).count():
                continue
            else:
                try:
                    url = result[code]["url"]
                    data = await crawl_answer(url=url)
                    end_url = data["end_url"]
                    answer = data["answer"]
                    catalogue = data["catalogue"]
                    async with AsyncClient(headers=headers) as client:
                        end_jpg = await client.get(end_url, timeout=10)
                    cover = end_jpg.content
                    await Answer.create(
                        time=time.time(),
                        code=code,
                        catalogue=catalogue,
                        url=url.replace("index.html", "m.html").replace("http://", "https://"),
                        end_url=end_url,
                        answer=answer,
                        cover=cover
                    )
                    logger.opt(colors=True).success(f"<u><y>青年大学习</y></u> <m>{catalogue}</m> <g>更新成功!</g>")
                    admin = getConfig()
                    content = await get_login_qrcode()
                    if admin["URL_STATUS"]:
                        await bot.send_private_msg(user_id=admin["SUPERUSER"], message=MessageSegment.text(
                            f"检测到青年大学习有更新，下周一为{catalogue},详细信息请点击链接登录后台查看，如打不开链接，请复制链接到浏览器d(´ω｀*)\n") + MessageSegment.text(
                            content["url"]))
                    await bot.send_private_msg(user_id=admin["SUPERUSER"], message=MessageSegment.text(
                        f"检测到青年大学习有更新，下周一为{catalogue},详细信息请扫码登录后台查看d(´ω｀*)") + MessageSegment.image(
                        content["content"]))
                except Exception as e:
                    logger.error(e)
    except Exception as e:
        logger.error(e)
    # try:
    await update_jiangxi()
    # except Exception as e:
    #     logger.error(e)
    await update_shandong()
    await update_shanxi()


@scheduler.scheduled_job('cron', second='*/10', misfire_grace_time=10)
async def check_apply():
    try:
        bot: Bot = get_bot()
    except ValueError as e:
        return
    apply_list = await AddUser.filter(status="未通过").values()

    for item in apply_list:
        result = await User.filter(user_id=item["user_id"], group_id=item["group_id"]).count()
        if result:
            await AddUser.filter(id=item["id"]).update(status="已通过")
            await bot.send_group_msg(group_id=item["group_id"],
                                     message=MessageSegment.at(user_id=item["user_id"]) + MessageSegment.text(
                                         "信息绑定成功，可发指令：提交大学习 提交最新一期青年大学习哦( • ̀ω•́ )✧"))
            await asyncio.sleep(2)
            continue
        now_time = int(time.time())
        if (now_time - item["time"]) > 180:
            await AddUser.filter(id=item["id"]).update(status="已过期")
            await bot.send_group_msg(group_id=item["group_id"],
                                     message=MessageSegment.at(user_id=item["user_id"]) + MessageSegment.text(
                                         "添加申请已过期，请重新发 添加大学习 指令进行申请( • ̀ω•́ )✧"))
            await asyncio.sleep(2)
        else:
            continue


@scheduler.scheduled_job('cron', day_of_week='0', hour='0', minute='0', id='clear', timezone="Asia/Shanghai")
async def clear():
    try:
        result = await Area.all().values()
        for item in result:
            await Area.filter(id=item["id"]).update(status=False)
        logger.opt(colors=True).success(
            f"<u><y>[大学习数据库]</y></u> <m>地区最新一期状态</m> <g>重置成功!</g>")
    except Exception as e:
        logger.opt(colors=True).error(
            f"<u><y>[大学习数据库]</y></u> <m>地区最新一期状态</m> <r重置失败：{e}</r>")



import asyncio
import datetime
import random
import socket
import time

from nonebot import get_driver, on_notice, require, get_bot
from nonebot import on_command, logger
from nonebot.adapters.onebot.v11 import GroupMessageEvent, MessageSegment, Bot, GROUP, Message, MessageEvent, \
    PokeNotifyEvent
from nonebot.params import ArgStr, T_State, CommandArg
from nonebot.permission import SUPERUSER
from nonebot.rule import Rule

from .path import getConfig, saveConfig
from .rule import must_command, check_poke, must_group, must_leader
from .utils import get_end_pic, distribute_area, distribute_area_url, get_answer_pic, get_qrcode, get_login_qrcode, \
    to_hash
from ..models.accuont import User, AddUser
from ..models.dxx import Area, Answer, PushList

scheduler = require('nonebot_plugin_apscheduler').scheduler
SUPERS = get_driver().config.superusers
CONFIG = getConfig()

end_pic = on_command("end_pic", aliases={"完成截图", "大学习截图"}, permission=SUPERUSER | GROUP,
                     rule=Rule(must_group),
                     priority=50)

submit = on_command("submit", aliases={"提交大学习"}, permission=SUPERUSER | GROUP, rule=Rule(must_group),
                    priority=50)
add = on_command("add_dxx", aliases={"添加大学习"}, permission=GROUP, rule=must_group, priority=50)
my_info = on_command("my_info", aliases={"我的大学习"}, permission=SUPERUSER | GROUP,
                     rule=Rule(must_command, must_group), priority=50)
poke_notify = on_notice(priority=60, rule=check_poke)
answer_pic = on_command("answer_pic", aliases={"答案截图", "大学习"}, rule=Rule(must_command, must_group),
                        permission=SUPERUSER | GROUP,
                        priority=50)
finish_dxx = on_command("finish_dxx", aliases={"完成大学习", "全员大学习"},
                        rule=Rule(must_command, must_group, must_leader), permission=GROUP | SUPERUSER, priority=50)
reset_config = on_command("reset_config", aliases={"重置配置", "刷新配置"}, permission=SUPERUSER, rule=must_command,
                          priority=50)
reset_password = on_command("reset_password", aliases={"重置密码"}, permission=GROUP,
                            rule=Rule(must_command, must_group), priority=50)
delete_dxx = on_command("delete_dxx", aliases={"删除大学习"}, priority=50, rule=Rule(must_command, must_group))


@end_pic.handle()
async def end_(msg: Message = CommandArg()) -> None:
    if str(msg):
        result = await Answer.filter(catalogue=str(msg)).order_by("time").values()
        if result:
            end_png = await get_end_pic(id=result[-1]["id"])
            title = result[-1]["catalogue"]
        else:
            result = await Answer.all().order_by("time").values()
            end_png = await get_end_pic(id=result[-1]["id"])
            title = result[-1]["catalogue"]
    else:
        result = await Answer.all().order_by("time").values()
        end_png = await get_end_pic(id=result[-1]["id"])
        title = result[-1]["catalogue"]
    await end_pic.finish(
        message=MessageSegment.text(f"青年大学习{title}完成截图") + MessageSegment.image(end_png),
        at_sender=True)


@submit.handle()
async def submit_(event: GroupMessageEvent, msg: Message = CommandArg()) -> None:
    user_id = event.user_id
    result = await User.filter(user_id=user_id).values()
    if result:
        area = result[0]['area']
        if str(msg):
            catalogueResult = await Answer.filter(catalogue=str(msg)).values()
            if catalogueResult:
                catalogue = str(msg)
            else:
                await submit.send(message=MessageSegment.text("无效期数，将提交最新一期大学习"), at_sender=True)
                catalogue = None
        else:
            catalogue = None
        data = await distribute_area(user_id=user_id, area=area, catalogue=catalogue)
        if data['status'] == 0:
            title = data["catalogue"]
            message = f'青年大学习{title}提交成功( ･´ω`･ )'
            answer = await Answer.filter(catalogue=title).order_by("time").values()
            config = getConfig()
            content = await get_login_qrcode()
            if answer:
                end_png = await get_end_pic(id=answer[-1]["id"])
            else:
                answer = await Answer.all().order_by("time").values()
                end_png = await get_end_pic(id=answer[-1]["id"])
                title = answer[-1]["title"]
            if config["URL_STATUS"]:
                await submit.send(message=MessageSegment.text(message) + MessageSegment.text(
                    f"\n请点击链接登录查看,如QQ点击无法打开，请复制链接到浏览器打开\n{content['url']}"),
                                  at_sender=True)
            else:
                await submit.send(message=MessageSegment.text(message) + MessageSegment.image(content['content']),
                                  at_sender=True)
            await asyncio.sleep(1)
            await submit.finish(
                message=MessageSegment.text(f"青年大学习{title}完成截图") + MessageSegment.image(end_png),
                at_sender=True)
        await submit.finish(message=MessageSegment.text(data['msg']), at_sender=True)
    else:
        await submit.finish(message=MessageSegment.text("用户数据不存在！请使用 添加大学习 指令添加(｡･ω･｡)"),
                            at_sender=True)


@add.handle()
async def add_(state: T_State, event: GroupMessageEvent, msg: Message = CommandArg()) -> None:
    user_id = event.user_id
    if await User.filter(user_id=user_id).count():
        await add.finish(message=MessageSegment.text("你已经添加过了，不要重复添加哦( • ̀ω•́ )✧"), at_sender=True,
                         reply_message=True)
    if str(msg):
        state['province'] = str(msg)


@add.got(key="province", prompt="请输入需要添加的省份或回复 取消 停止操作！")
async def add_(event: GroupMessageEvent, province: str = ArgStr("province")) -> None:
    group_id = event.group_id
    user_id = event.user_id
    config = getConfig()
    if province in ["取消", "No", "停止", "NO"]:
        await add.finish(message=MessageSegment.text("操作取消！φ(>ω<*) "), at_sender=True)
    if await Area.filter(area=province).count():
        url = await distribute_area_url(province=province, user_id=user_id, group_id=group_id)
        if province in ["上海", "浙江"]:
            content = await get_qrcode(user_id=user_id, group_id=group_id, area=province)
            if config["URL_STATUS"]:
                result = await add.send(
                    message=MessageSegment.text(f"请复制链接到微信点击打开进行绑定( ･´ω`･ )\n{content['url']}"),
                    at_sender=True,
                    reply_message=True)
            else:
                result = await add.send(
                    message=MessageSegment.text("请使用微信扫码进行绑定( ･´ω`･ )") + MessageSegment.image(
                        content["content"]), at_sender=True,
                    reply_message=True)
        else:
            if config["URL_STATUS"]:
                result = await add.send(
                    message=MessageSegment.text(
                        f"请点击链接进入网页添加绑定，如QQ无法打开链接，请复制链接到浏览器( ･´ω`･ )\n{url['url']}"),
                    at_sender=True,
                    reply_message=True)
            else:
                result = await add.send(
                    message=MessageSegment.text(f"请扫码进入网页添加绑定( ･´ω`･ )") + MessageSegment.image(
                        url['content']),
                    at_sender=True,
                    reply_message=True)
        await AddUser.create(
            time=time.time(),
            user_id=user_id,
            group_id=group_id,
            area=province,
            message_id=result["message_id"],
            status="未通过"
        )
    else:
        await add.reject(
            prompt=MessageSegment.text(
                "该省份暂不支持或输入省份名称（名称不要带省字）错误，请重新输入或回复 取消 停止操作( ･´ω`･ )"),
            at_sender=True,
            reply_message=True)


@my_info.handle()
async def my_info_(event: MessageEvent) -> None:
    user_id = event.user_id
    config = getConfig()
    if await User.filter(user_id=user_id).count():
        content = await get_login_qrcode()
        if config["URL_STATUS"]:
            await my_info.finish(
                message=MessageSegment.text(
                    f'请点击链接登录查看哦，如QQ打不开链接，请复制链接到浏览器(｡･ω･｡)\n{content["url"]}'),
                at_sender=True)
        else:
            await my_info.finish(
                message=MessageSegment.text('请扫码登录查看哦(｡･ω･｡)') + MessageSegment.image(content['content']),
                at_sender=True)
    else:
        await my_info.finish(
            message=MessageSegment.text("你还没有绑定大学习哦ヾ(ｏ･ω･)ﾉ，使用 添加大学习 指令进行绑定信息吧( • ̀ω•́ )✧"),
            at_sender=True)


@poke_notify.handle()
async def poke_notify_(bot: Bot, event: PokeNotifyEvent):
    config = getConfig()
    if not config["POKE_SUBMIT"]:
        return
    try:
        group_id = event.group_id
    except AttributeError:
        group_id = None
    user_id = event.user_id
    target_id = event.target_id
    if target_id != int(bot.self_id):
        return
    if group_id:
        result = await User.filter(user_id=user_id).values()
        if result:
            area = result[0]['area']
            data = await distribute_area(user_id=user_id, area=area)
            if data['status'] == 0:
                title = data["catalogue"]
                message = f'青年大学习{title}提交成功( ･´ω`･ )'
                answer = await Answer.filter(catalogue=title).order_by("time").values()
                if answer:
                    end_png = await get_end_pic(id=answer[-1]["id"])
                else:
                    answer = await Answer.all().order_by("time").values()
                    end_png = await get_end_pic(id=answer[-1]["id"])
                    title = answer[-1]["title"]
                content = await get_login_qrcode()
                if config["URL_STATUS"]:
                    await poke_notify.send(
                        message=MessageSegment.text(message) + MessageSegment.text(
                            f"\n请点击链接登录查看,如QQ点击无法打开，请复制链接到浏览器打开\n{content['url']}"),
                        at_sender=True)
                else:
                    await poke_notify.send(
                        message=MessageSegment.text(message + "\n个人信息请扫码登录查看") + MessageSegment.image(
                            content["content"]), at_sender=True)
                await asyncio.sleep(1)
                await poke_notify.finish(
                    message=MessageSegment.text(f"青年大学习{title}完成截图") + MessageSegment.image(end_png),
                    at_sender=True,
                    reply_message=True)
            await poke_notify.finish(message=MessageSegment.text(data['msg']), at_sender=True)
        else:
            await poke_notify.finish(
                message=MessageSegment.text("用户数据不存在！请使用 添加大学习 指令进行绑定(*^▽^*)"), at_sender=True,
                reply_message=True)
    else:
        await bot.send_private_msg(user_id=user_id,
                                   message=MessageSegment.at(user_id) + MessageSegment.text("别戳啦(~￣△￣)~"))


@answer_pic.handle()
async def answer_pic_() -> None:
    await answer_pic.finish(message=MessageSegment.image(await get_answer_pic()), at_sender=True)


@finish_dxx.got(key="msg", prompt="是否提交团支部全体成员最新一期青年大学习？（是|否）")
async def finish(event: GroupMessageEvent, msg: str = ArgStr("msg")) -> None:
    if msg not in ["是", "yes", "Y", "y", "YES", "true"]:
        await finish_dxx.finish(message=MessageSegment.text("操作取消(*^▽^*)"), at_sender=True)
    else:
        await finish_dxx.send(message=MessageSegment.text("开始提交(*￣︶￣)"), at_sender=True)
    group_id = event.group_id
    user_id = event.user_id
    result = await User.filter(leader=user_id, group_id=group_id).values()
    if result:
        answer_result = await Answer.all().order_by('time').values()
        catalogue = answer_result[-1]["catalogue"]
        for item in result:
            if item["catalogue"] == catalogue:
                continue
            else:
                await distribute_area(user_id=item["user_id"], area=item["area"])
                await asyncio.sleep(random.randint(10, 15))
    await finish_dxx.finish(message=MessageSegment.text("提交完成！"), at_sender=True)


@reset_config.got(key="msg", prompt="是否重置大学习配置为默认配置？（是|否）")
async def reset_config_(event: MessageEvent, msg: str = ArgStr("msg")) -> None:
    user_id = event.user_id
    if msg not in ["是", "yes", "Y", "y", "YES", "true"]:
        await reset_config.finish(message=MessageSegment.text("操作取消(*^▽^*)"), at_sender=True)
    else:
        try:
            ip = get_driver().config.dxx_ip
        except AttributeError:
            s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
            s.connect(('119.29.29.29', 12345))
            ip = s.getsockname()[0]
        data = {
            "TOKEN_TIME": 30,
            "SUPERUSER": user_id,
            "KEY": "d82ffad91168fb324ab6ebc2bed8dacd43f5af8e34ad0d1b75d83a0aff966a06",
            "ALGORITHM": "HS256",
            "PASSWORD": await to_hash("admin"),
            "DXX_IP": ip
        }
        status = saveConfig(data=data)
        if status:
            await reset_config.finish(message=MessageSegment.text("重置成功(oﾟ▽ﾟ)o  "), at_sender=True,
                                      reply_message=True)
        else:
            await reset_config.finish(message=MessageSegment.text("重置失败╮(╯﹏╰）╭ "), at_sender=True,
                                      reply_message=True)


@reset_password.handle()
async def reset_password_(event: MessageEvent) -> None:
    user_id = event.user_id
    result = await User.filter(user_id=user_id).count()
    if not result:
        await reset_password.finish(message=MessageSegment.text("重置失败，用户数据不存在！( ･´ω`･ )"), at_sender=True,
                                    reply_message=True)


@reset_password.got(key="msg", prompt="是否重置大学习登录密码？（是|否）")
async def reset_password_(event: MessageEvent, msg: str = ArgStr("msg")) -> None:
    user_id = event.user_id
    if msg not in ["是", "yes", "Y", "y", "YES", "true"]:
        await reset_password.finish(message=MessageSegment.text("操作取消(*^▽^*)"), at_sender=True)
    else:
        await User.filter(user_id=user_id).update(
            password=await to_hash(str(user_id))
        )
        await reset_password.finish(message=MessageSegment.text("登录密码重置成功，默认为用户QQ(๑*◡*๑)"),
                                    at_sender=True)


@delete_dxx.handle()
async def delete_dxx_(event: GroupMessageEvent, state: T_State) -> None:
    user_id = event.user_id
    result = await User.filter(user_id=user_id).values("id")
    if result:
        state["id"] = result[0]["id"]
    else:
        await delete_dxx.finish(message=MessageSegment.text("操作失败，用户数据不存在(*^▽^*)"), at_sender=True,
                                reply_message=True)


@delete_dxx.got(key="msg", prompt="是否删除大学习数据？（是|否）")
async def delete_dxx_(state: T_State, msg: str = ArgStr("msg")) -> None:
    if msg not in ["是", "yes", "Y", "y", "YES", "true"]:
        await delete_dxx.finish(message=MessageSegment.text("操作取消(*^▽^*)"), at_sender=True)
    else:
        await User.filter(id=state["id"]).delete()
        await delete_dxx.finish(message=MessageSegment.text("删除成功(*^▽^*)"), at_sender=True)


@scheduler.scheduled_job('cron', day_of_week='0', hour=CONFIG["DXX_REMIND_HOUR"], minute=CONFIG["DXX_REMIND_MINUTE"],
                         id='push_dxx', timezone="Asia/Shanghai")
async def push_dxx() -> None:
    config = getConfig()
    if not config["DXX_REMIND"]:
        return
    try:
        bot: Bot = get_bot()
    except ValueError as e:
        logger.error(e)
        return None
    answer_result = await Answer.all().order_by('time').values()
    if (int(time.time()) - answer_result[-1]["time"]) > 259200:
        return None
    else:
        catalogue = answer_result[-1]["catalogue"]
        end_png = await get_end_pic(id=answer_result[-1]["id"])
        now_time = datetime.datetime.fromtimestamp(answer_result[-1]["time"]).strftime("%Y年%m月%d日 %H:%M:%S")
        message = f'\n本周的大学习开始喽!\n{catalogue}\n更新时间：{now_time}\n答案见图一\n完成截图见图二\nPs:当11:00:00以后，可使用 提交大学习 指令或戳一戳Bot完成大学习!'
        push_list = await PushList.filter(status=True).values()
        for item in push_list:
            try:
                await bot.send_group_msg(group_id=item["group_id"],
                                         message=MessageSegment.at("all") + MessageSegment.text(
                                             message) + MessageSegment.image(
                                             await get_answer_pic()) + MessageSegment.image(end_png))
                await asyncio.sleep(random.randint(15, 30))
            except Exception as e:
                logger.error(e)
                continue


@scheduler.scheduled_job('cron', day_of_week='0', hour=CONFIG["AUTO_SUBMIT_HOUR"], minute=CONFIG["AUTO_SUBMIT_MINUTE"],
                         id='auto_dxx', timezone="Asia/Shanghai")
async def auto_dxx() -> None:
    config = getConfig()
    if not config["AUTO_SUBMIT"]:
        return
    answer_result = await Answer.all().order_by('time').values()
    if (int(time.time()) - answer_result[-1]["time"]) > 259200:
        return None
    else:
        user_list = await User.all().values("id", "area", "catalogue", "user_id")
        catalogue = answer_result[-1]["catalogue"]
        for item in user_list:
            result = await User.filter(id=item["id"]).values("id", "area", "catalogue", "user_id", "auto_submit")
            if result[0]["catalogue"] == catalogue or not result[0]["auto_submit"]:
                continue
            else:
                await distribute_area(user_id=item["user_id"], area=item["area"])
                await asyncio.sleep(random.randint(10, 20))



from amis import App, PageSchema, TableColumn, CRUD, ActionType, LevelEnum
from amis import Html, Page, Form, InputText, Switch, InputTime, InputNumber
from amis import Tpl, Dialog, DisplayModeEnum, Select, Flex, Service, Property

from .addArea import areaPage
from .log import page_log

logo = Html(html=f'''
<p align="center">
    <a href="https://github.com/YouthLearning/TeenStudy/">
        <img src="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
         width="256" height="256" alt="TeenStudy">
    </a>
</p>
<h2 align="center">大学习自动提交</h2>
<div align="center">
    <a href="https://github.com/YouthLearning/TeenStudy/" target="_blank">
    Github仓库</a>
    <a href="https://jq.qq.com/?_wv=1027&k=NGFEwXyS" target="_blank">QQ反馈群</a>
    <a href="http://qm.qq.com/cgi-bin/qm/qr?_wv=1027&k=2PQucjirnkHyPjoS1Pkr-ai2aPGToBKm" target="_blank">QQ体验群</a>
</div>
<br>
''')
github_logo = Tpl(className='w-full',
                  tpl='<div class="flex justify-between"><div></div><div><a href="https://github.com/YouthLearning/TeenStudy" target="_blank" title="Github 仓库"><i class="fab fa-github fa-2x"></i></a></div></div>')
header = Flex(className='w-full', justify='flex-end', alignItems='flex-end', items=[github_logo,
                                                                                    {
                                                                                        "type": "button",
                                                                                        "label": "退出",
                                                                                        "onEvent": {
                                                                                            "click": {
                                                                                                "actions": [
                                                                                                    {
                                                                                                        "actionType": "confirmDialog",
                                                                                                        "args": {
                                                                                                            "title": "操作确认",
                                                                                                            "msg": "是否退出系统？"
                                                                                                        }},

                                                                                                    {
                                                                                                        "actionType": "custom",
                                                                                                        "script": "window.location.href = '/TeenStudy/login';window.localStorage.clear();window.sessionStorage.clear();\n //event.stopPropagation();"
                                                                                                    }

                                                                                                ]
                                                                                            },
                                                                                        }}
                                                                                    ])
"""机器人状态面板"""
status = Service(
    api='/TeenStudy/api/status',
    interval=60000,
    body=[Property(
        title='机器人信息',
        column=2,
        items=[
            Property.Item(
                label='Bot昵称',
                content='${nickname}'
            ),
            Property.Item(
                label='Bot qq号',
                content='${bot_id}'
            ),
            Property.Item(
                label='Bot好友数量',
                content='${friend_count}'
            ),
            Property.Item(
                label='Bot群聊数量',
                content='${group_count}'
            ),
            Property.Item(
                label='Bot启动时间',
                content='${start_time}'
            ),
            Property.Item(
                label='系统启动时间',
                content='${system_start_time}'
            ),
            Property.Item(
                label='通知群数量',
                content='${notice_count}'
            ),
            Property.Item(
                label='用户数量',
                content='${user_count}'
            ),
            Property.Item(
                label='支持地区数量',
                content='${area_count}'
            ), Property.Item(
                label='最新一期大学习',
                content='${catalogue}'
            ), Property.Item(
                label='公网访问IP',
                content='${ip}'
            ),
            Property.Item(
                label='CPU占用率',
                content='${cpu_percent}'
            ),
            Property.Item(
                label='RAM占用率',
                content='${ram_percent}'
            ),
            Property.Item(
                label='SWAP占用率',
                content='${swap_percent}',
            ),
        ]
    )]
)
"""提交记录模板"""
record_table = CRUD(mode='table',
                    title='',
                    syncLocation=False,
                    api='/TeenStudy/api/get_records',
                    interval=60000,
                    type='crud',
                    headerToolbar=[ActionType.Ajax(label='删除所有提交记录',
                                                   level=LevelEnum.warning,
                                                   confirmText='确定要删除所有提交记录吗？',
                                                   api='delete:/TeenStudy/api/delete_all?type=records'),
                                   "bulkActions", "reload"],
                    itemActions=[
                        ActionType.Ajax(tooltip='删除',
                                        icon='fas fa-times text-danger',
                                        confirmText='删除该条提交记录',
                                        api='delete:/TeenStudy/api/delete_record?id=${id}')
                    ],
                    footable=True,
                    columns=[
                        TableColumn(label='用户ID', name='user_id', searchable=True),
                        TableColumn(label='姓名', name='name', searchable=True),
                        TableColumn(label='提交地区', name='area', searchable=True),
                        TableColumn(label='学校名称', name='university', searchable=True),
                        TableColumn(label='学院名称', name='college', searchable=True),
                        TableColumn(label='团支部', name='organization', searchable=True),
                        TableColumn(label='提交期数', name='catalogue', searchable=True),
                        TableColumn(tppe="tpl", label='提交状态', tpl='${status===true?"成功":"失败"}', name="status",
                                    searchable=True),
                        TableColumn(type='tpl', tpl='${time|date:YYYY-MM-DD HH\\:mm\\:ss}',
                                    label='提交时间',
                                    name='time', sortable=True)
                    ],
                    bulkActions=[
                        ActionType.Ajax(label='批量删除',
                                        level=LevelEnum.warning,
                                        confirmText="确定要批量删除？",
                                        api="delete:/TeenStudy/api/delete_records?ids=${ids|raw}")])
answer_table = CRUD(mode='table',
                    title='',
                    syncLocation=False,
                    api='/TeenStudy/api/get_answers',
                    interval=60000,
                    type='crud',
                    headerToolbar=[ActionType.Ajax(label='删除青年大学习期数',
                                                   level=LevelEnum.warning,
                                                   confirmText='确定要删除青年大学习期数吗？',
                                                   api='delete:/TeenStudy/api/delete_all?type=answers'),
                                   "bulkActions", "reload"],
                    itemActions=[
                        ActionType.Ajax(tooltip='删除',
                                        icon='fas fa-times text-danger',
                                        confirmText='删除该期青年大学习',
                                        api='delete:/TeenStudy/api/delete_answer?id=${id}')
                    ],
                    footable=True,
                    columns=[
                        TableColumn(label='数据库ID', name='id'),
                        TableColumn(label='大学习ID', name='code'),
                        TableColumn(label='大学习期数', name='catalogue', searchable=True),
                        TableColumn(type='tpl', tpl='${url|truncate:20}', label='官方网址',
                                    name='url',
                                    popOver={'mode': 'dialog', 'title': '完整网址',
                                             'className': 'break-all',
                                             'body': {'type': 'tpl',
                                                      'tpl': '${url}'}}, copyable=True),
                        TableColumn(type='tpl', tpl='${end_url|truncate:20}', label='完成截图网址',
                                    name='end_url',
                                    popOver={'mode': 'dialog', 'title': '完整网址',
                                             'className': 'break-all',
                                             'body': {'type': 'tpl',
                                                      'tpl': '${end_url}'}}, copyable=True),
                        TableColumn(type='tpl', tpl='${answer|truncate:20}', label='答案',
                                    name='answer',
                                    popOver={'mode': 'dialog', 'title': '完整答案',
                                             'className': 'break-all',
                                             'body': {'type': 'tpl',
                                                      'tpl': '${answer}'}}),
                        TableColumn(type='tpl', tpl='${time|date:YYYY-MM-DD HH\\:mm\\:ss}',
                                    label='更新时间',
                                    name='time', sortable=True)
                    ],
                    bulkActions=[
                        ActionType.Ajax(label='批量删除',
                                        level=LevelEnum.warning,
                                        confirmText="确定要批量删除？",
                                        api="delete:/TeenStudy/api/delete_answers?ids=${ids|raw}")])

"""Web端配置表"""
setting_table = Form(
    title="Web端配置",
    submitText="保存",
    api="put:/TeenStudy/api/change_settings",
    initApi="get:/TeenStudy/api/get_settings",
    body=[
        InputText(
            name="SUPERUSER",
            label="超管登录账号",
            description="超管登录账号",
            showCounter=True,
            value="${SUPERUSER}",
            trimContents=True,
            maxLength=10,
            required=True,
            clearable=True
        ),
        InputText(
            name="password",
            label="超管登录密码",
            description="超管登录密码，可不填，默认是admin",
            showCounter=True,
            maxLength=16,
            value="",
            trimContents=True,
            required=False, clearable=True

        ),
        InputText(
            name="TOKEN_TIME",
            label="token失效时间",
            description="Web访问token失效时间，单位为分钟",
            showCounter=True,
            maxLength=3,
            value="${TOKEN_TIME}",
            trimContents=True,
            resetValue=30,
            required=True,
            clearable=True
        ),
        InputText(
            name="KEY",
            label="加密秘钥",
            description="加密秘钥，为64位哈希散列值，用于生成token",
            showCounter=True,
            maxLength=64,
            value="${KEY}",
            resetValue="d82ffad91168fb324ab6ebc2bed8dacd43f5af8e34ad0d1b75d83a0aff966a06",
            trimContents=True,
            required=True, clearable=True
        ),
        InputText(
            name="ALGORITHM",
            label="加密算法",
            description="生成token的算法",
            value="${ALGORITHM}",
            trimContents=True,
            showCounter=True,
            required=True,
            resetValue="HS256",
            clearable=True
        ),
        InputText(
            name="DXX_IP",
            label="公网访问IP",
            value="${DXX_IP}",
            description="公网访问IP，用于外网访问",
            showCounter=True,
            trimContents=True,
            resetValue="0.0.0.0",
            required=True,
            clearable=True
        ),
        InputNumber(
            name="DXX_PORT",
            displayMode="enhance",
            label="公网访问端口",
            value="${DXX_PORT}",
            min=0,
            max=65535,
            description="公网访问端口，用于外网访问，不配置域名和反向代理请勿修改",
            showCounter=True,
            trimContents=True,
            resetValue=8080,
            required=True,
            clearable=True
        ),
        Switch(
            name="URL_STATUS",
            label="二维码转链接开关",
            value="${URL_STATUS}",
            onText='开启',
            offText='关闭',
            required=True,
        ),
        Switch(
            name="POKE_SUBMIT",
            label="戳一戳提交大学习开关",
            value="${POKE_SUBMIT}",
            onText='开启',
            offText='关闭',
            required=True,
        ),
        Switch(
            name="DXX_REMIND",
            label="大学习提醒开关",
            value="${DXX_REMIND}",
            onText='开启',
            offText='关闭',
            required=True,
        ),
        InputTime(
            name="remind",
            label="提醒时间",
            type="input-time",
            required=True,
            value="${remind}",
        ),
        Switch(
            name="AUTO_SUBMIT",
            label="大学习自动提交开关",
            value="${AUTO_SUBMIT}",
            onText='开启',
            offText='关闭',
            required=True,
        ),
        InputTime(
            name="auto",
            label="自动提交时间",
            type="input-time",
            required=True,
            value="${auto}",
        ),
    ]
)
"""申请记录模板"""
request_table = CRUD(mode='table',
                     title='',
                     syncLocation=False,
                     api='/TeenStudy/api/get_requests',
                     interval=60000,
                     type='crud',
                     headerToolbar=[ActionType.Ajax(label='删除所有申请记录',
                                                    level=LevelEnum.warning,
                                                    confirmText='确定要删除所有申请记录吗？',
                                                    api='delete:/TeenStudy/api/delete_all?type=requests'),
                                    "bulkActions", "reload"],
                     itemActions=[
                         ActionType.Ajax(tooltip='删除',
                                         icon='fas fa-times text-danger',
                                         confirmText='删除该条申请记录',
                                         api='delete:/TeenStudy/api/delete_request?id=${id}')
                     ],
                     footable=True,
                     columns=[
                         TableColumn(label='申请ID', name='user_id', searchable=True),
                         TableColumn(label='申请群号', name='group_id', searchable=True),
                         TableColumn(label='申请地区', name='area', searchable=True),
                         TableColumn(label='申请状态', name='status', searchable=True),
                         TableColumn(type='tpl', tpl='${time|date:YYYY-MM-DD HH\\:mm\\:ss}',
                                     label='申请时间',
                                     name='time', sortable=True)
                     ],
                     bulkActions=[
                         ActionType.Ajax(label='批量删除',
                                         level=LevelEnum.warning,
                                         confirmText="确定要批量删除？",
                                         api="delete:/TeenStudy/api/delete_requests?ids=${ids|raw}")])

"""推送群聊模板"""
push_table = CRUD(mode='table',
                  title='',
                  syncLocation=False,
                  api='/TeenStudy/api/get_push_list',
                  type='crud',
                  headerToolbar=[ActionType.Ajax(label='删除所有推送群聊',
                                                 level=LevelEnum.warning,
                                                 confirmText='确定要删除所有推送群聊吗？',
                                                 api='delete:/TeenStudy/api/delete_all?type=push_list'),
                                 "bulkActions", "reload", ActionType.Dialog(
                          label='添加推送群聊',
                          level=LevelEnum.info,
                          icon='fas fa-plus',
                          dialog=Dialog(title='添加推送群聊',
                                        size='lg',
                                        body=[
                                            Form(title='',
                                                 api='post:/TeenStudy/api/add_push',
                                                 submitText='添加',
                                                 mode=DisplayModeEnum.horizontal,
                                                 labelAlign='right',
                                                 body=[Select(
                                                     label="群聊",
                                                     name="groups",
                                                     description="需要推送的群组",
                                                     checkAll=True,
                                                     source="get:/TeenStudy/api/get_group_list",
                                                     value='',
                                                     multiple=True,
                                                     required=True,
                                                     searchable=True,
                                                     joinValues=False,
                                                     extractValue=True,
                                                     statistics=True,
                                                 )
                                                 ])])
                      )],
                  itemActions=[
                      ActionType.Ajax(tooltip='删除',
                                      icon='fas fa-times text-danger',
                                      confirmText='删除该推送群聊吗',
                                      api='delete:/TeenStudy/api/delete_push?id=${id}')
                  ],
                  footable=True,
                  columns=[
                      TableColumn(label='数据库ID', name='id'),
                      TableColumn(label='机器人ID', name='self_id', searchable=True, ),
                      TableColumn(label='通知群号', name='group_id'),
                      TableColumn(label='添加人员', name='user_id', searchable=True, ),
                      TableColumn(type="tpl", label='提交状态', tpl='${status==true?"开启":"关闭"}', name="status",
                                  searchable=True, ),
                      TableColumn(type='tpl', tpl='${time|date:YYYY-MM-DD HH\\:mm\\:ss}',
                                  label='添加时间',
                                  name='time', sortable=True)
                  ],
                  bulkActions=[
                      ActionType.Ajax(label='批量删除',
                                      level=LevelEnum.warning,
                                      confirmText="确定要批量删除？",
                                      api="delete:/TeenStudy/api/delete_push?ids=${ids|raw}")])
page_detail = Page(title='', body=[logo, status])
admin_page = PageSchema(url='/TeenStudy/admin', label='首页', icon='fas fa-home', isDefaultPage=True,
                        schema=page_detail)
"""成员列表页"""

admin_app = App(brandName='TeenStudy',
                logo='https://img1.imgtp.com/2023/10/06/NChUNeiA.png',
                header=header,
                pages=[{
                    'children': [
                        admin_page,
                        PageSchema(icon='far fa-user-circle', vendor="", label='成员管理',
                                   children=areaPage),
                        PageSchema(url="/TeenStudy/notice", label='推送列表', icon='fas fa-bell', vendor="",
                                   schema=Page(title='', body=[push_table])),
                        PageSchema(url="/TeenStudy/request", label='申请记录', icon='fas fa-info-circle', vendor="",
                                   schema=Page(title='', body=[request_table])),
                        PageSchema(url="/TeenStudy/answer", label='大学习列表', icon='fas fa-book-open', vendor="",
                                   schema=Page(title='', body=[answer_table])),
                        PageSchema(url="/TeenStudy/records", label='提交记录', icon='fas fa-code-branch', vendor="",
                                   schema=Page(title='', body=[record_table])),
                        PageSchema(url="/TeenStudy/setting", label='配置', icon='fas fa-cogs', vendor="",
                                   schema=Page(title='', body=[setting_table])),
                        page_log
                    ]}],
                footer=Html(
                    html=f'<div class="p-2 text-center bg-blue-100">Copyright © 2022 - 2023 <a href="https://github.com/YouthLearning/TeenStudy" target="_blank" class="link-secondary">TeenStudy v.0.2.5</a> X<a target="_blank" href="https://github.com/baidu/amis" class="link-secondary" rel="noopener"> amis v.3.4.3</a></div>'))



import random
import string
import time

from nonebot import logger

from ...models.accuont import User
from ...utils.utils import to_hash


async def get_openid() -> str:
    return ''.join(random.sample(string.ascii_letters + string.digits, 28))


async def write_to_database(data: dict) -> bool:
    try:
        if data["password"]:
            data["password"] = await to_hash(str(data["password"]))
        else:
            data["password"] = await to_hash(str(data["user_id"]))
        if await User.filter(user_id=int(data["user_id"])).count():
            return False
        if data["area"] in ["湖北"]:
            data["openid"] = await get_openid()
        start = {
            "time": time.time(),
            "user_id": None,
            "area": None,
            "name": None,
            "password": None,
            "group_id": None,
            "gender": None,
            "mobile": None,
            "leader": None,
            "openid": None,
            "dxx_id": None,
            "university_type": None,
            "university_id": None,
            "university": None,
            "college_id": None,
            "college": None,
            "organization_id": None,
            "organization": None,
            "token": None,
            "cookie": None,
            "catalogue": None,
            "auto_submit": True,
            "commit_time": None
        }
        start.update(data)
        await User.create(**start)
        return True
    except Exception as e:
        logger.error(e)
        return False



from amis import LevelEnum, ButtonGroupSelect, \
    Log, Alert, Form, Select, Group, PageSchema, Page

from ...utils.path import getConfig

CONFIG = getConfig()
SECRET_KEY = CONFIG["KEY"]
select_log_num = Select(
    label='日志数量',
    name='log_num',
    value=100,
    options=[
        {
            'label': 100,
            'value': 100
        },
        {
            'label': 200,
            'value': 200
        },
        {
            'label': 300,
            'value': 300
        },
        {
            'label': 400,
            'value': 400
        },
        {
            'label': 500,
            'value': 500
        }
    ]
)

select_log_level = ButtonGroupSelect(
    label='日志等级',
    name='log_level',
    btnLevel=LevelEnum.light,
    btnActiveLevel=LevelEnum.warning,
    value='info',
    options=[
        {
            'label': 'INFO',
            'value': 'info',
            "level": "primary"
        },
        {
            'label': 'DEBUG',
            'value': 'debug',
            "level": "primary"
        }
    ]
)

log_page = Log(
    autoScroll=True,
    disableColor=False,
    placeholder='暂无日志数据...',
    operation=['stop', 'showLineNumber', 'filter'],
    source={
        'method': 'get',
        'url': '/TeenStudy/api/log?level=${log_level | raw}&num=${log_num | raw}',
        'headers': {
            'token': SECRET_KEY[:16]
        }
    }
)
page_detail = Page(title='', body=[Alert(level=LevelEnum.info,
                                         body='查看最近最多500条日志，不会自动刷新，需要手动点击两次"暂停键"来进行刷新，DEBUG日志需要Nonebot日志模式为DEBUG才能查看。'),
                                   Form(title="", interval=180000,
                                        body=[Group(body=[select_log_num, select_log_level]), log_page], submitText=''
                                        )])
page_log = PageSchema(url='/TeenStudy/log', label='运行日志', icon='fas fa-bug', schema=page_detail)
